Module: Neo4j::Community
- Defined in:
- lib/neo4j-community.rb,
lib/neo4j-community/version.rb
Constant Summary collapse
- VERSION =
"2.2.4.1"- NEO_VERSION =
"2.2.4"
Class Method Summary collapse
-
.ensure_version!(other, edition) ⇒ Object
This can be used by dependent gems to verify the Database versions have no mismatch.
- .jars_root ⇒ Object
- .load_jars! ⇒ Object
- .load_test_jars! ⇒ Object
- .test_jars_root ⇒ Object
Class Method Details
.ensure_version!(other, edition) ⇒ Object
This can be used by dependent gems to verify the Database versions have no mismatch.
26 27 28 29 |
# File 'lib/neo4j-community.rb', line 26 def self.ensure_version!(other, edition) return if ::Neo4j::Community::NEO_VERSION == other raise "Mismatch of Neo4j JAR versions. Already loaded neo4j-community JAR files '#{::Neo4j::Community::NEO_VERSION}' but neo4j-#{edition}: '#{other}'." end |
.jars_root ⇒ Object
7 8 9 |
# File 'lib/neo4j-community.rb', line 7 def self.jars_root File.join("#{File.dirname(__FILE__)}", "neo4j-community", "jars") end |
.load_jars! ⇒ Object
15 16 17 18 |
# File 'lib/neo4j-community.rb', line 15 def self.load_jars! require 'java' Dir["#{jars_root}/*.jar"].each {|jar| require jar } end |
.load_test_jars! ⇒ Object
20 21 22 23 |
# File 'lib/neo4j-community.rb', line 20 def self.load_test_jars! require 'java' Dir["#{test_jars_root}/*.jar"].each {|jar| require jar } end |
.test_jars_root ⇒ Object
11 12 13 |
# File 'lib/neo4j-community.rb', line 11 def self.test_jars_root File.join("#{File.dirname(__FILE__)}", "neo4j-community", "test-jars") end |